@@ -14,6 +14,15 @@ class IntrinsicCalibSession(CalibrationSession, ABC):
     def capture(self):
         # For an intrinsic calibration you are required to image the same Aruco markers from different 20 viewing
         # positions changing in rotation and translation of the camera
+        if not os.path.exists('CalibrationImages/Intrinsic/'):
+            os.mkdir('CalibrationImages/Intrinsic/')
+        if not os.path.exists('CapturedImages/Intrinsic/'):
+            os.mkdir('CapturedImages/Intrinsic/')
+        if not os.path.exists('CalibrationNumpyData/Intrinsic/'):
+            os.mkdir('CalibrationNumpyData/Intrinsic/')
+        if not os.path.exists('CapturedNumpyData/Intrinsic/'):
+            os.mkdir('CapturedNumpyData/Intrinsic/')
+            
         for i in range(self.no):
             # Display camera stream
             self.camera.viewCameraStream()
