@@ -8,8 +8,8 @@ from skimage import io
 from io import BytesIO
 from IPython.display import clear_output, Image, display, update_display
 import PIL
-from Cameras.liveDisplay import ptgCamStream, imgShow, patternDisplay
-from Cameras.PySpinCapture import PySpinCapture as psc
+from GhostScan.Cameras.liveDisplay import ptgCamStream, imgShow, patternDisplay
+from GhostScan.Cameras.PySpinCapture import PySpinCapture as psc
 import matplotlib.pyplot as plt
 
 class Basler(Camera, ABC):
